@@ -1,5 +1,5 @@
 /* Return specific DWARF attribute of a DIE.
-   Copyright (C) 2003, 2005 Red Hat, Inc.
+   Copyright (C) 2003, 2005, 2014 Red Hat, Inc.
    This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2003.
 
@@ -36,10 +36,7 @@
 
 
 Dwarf_Attribute *
-dwarf_attr (die, search_name, result)
-     Dwarf_Die *die;
-     unsigned int search_name;
-     Dwarf_Attribute *result;
+dwarf_attr (Dwarf_Die *die, unsigned int search_name, Dwarf_Attribute *result)
 {
   if (die == NULL)
     return NULL;
@@ -50,6 +47,6 @@ dwarf_attr (die, search_name, result)
   /* Always fill in the CU information.  */
   result->cu = die->cu;
 
-  return result->code == search_name ? result : NULL;
+  return result->valp != NULL && result->code == search_name ? result : NULL;
 }
 INTDEF(dwarf_attr)
