@@ -1,27 +1,19 @@
 /* Copyright (C) 2001-2010, 2012 Red Hat, Inc.
-   This file is part of Red Hat elfutils.
+   This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2001.
 
-   Red Hat elfutils is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by the
-   Free Software Foundation; version 2 of the License.
+   This file is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
-   Red Hat elfutils is distributed in the hope that it will be useful, but
+   elfutils is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with Red Hat elfutils; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA.
-
-   Red Hat elfutils is an included package of the Open Invention Network.
-   An included package of the Open Invention Network is a package for which
-   Open Invention Network licensees cross-license their patents.  No patent
-   license is granted, either expressly or impliedly, by designation as an
-   included package.  Should you wish to participate in the Open Invention
-   Network licensing program, please visit www.openinventionnetwork.com
-   <http://www.openinventionnetwork.com>.  */
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -34,7 +26,6 @@
 #include <libelf.h>
 #include <libintl.h>
 #include <locale.h>
-#include <mcheck.h>
 #include <stdio.h>
 #include <stdio_ext.h>
 #include <stdlib.h>
@@ -285,13 +276,8 @@ main (int argc, char *argv[])
   int remaining;
   int err;
 
-#ifndef NDEBUG
-  /* Enable memory debugging.  */
-  mtrace ();
-#endif
-
   /* Sanity check.  We always want to use the LFS functionality.  */
-  if (sizeof (off_t) != sizeof (off64_t))
+  if (sizeof (off_t) != 8)
     abort ();
 
   /* We use no threads here which can interfere with handling a stream.  */
@@ -1063,6 +1049,53 @@ parse_B_option_2 (const char *arg)
 }
 
 
+static inline int
+try (int fd, Elf *elf)
+{
+  int result = 0;
+
+  if (elf == NULL)
+    return 0;
+
+  if (elf_kind (elf) == ELF_K_ELF)
+    {
+      /* We have an ELF file.  We now can find out
+	 what the output format should be.  */
+      XElf_Ehdr_vardef(ehdr);
+
+      /* Get the ELF header of the object.  */
+      xelf_getehdr (elf, ehdr);
+      if (ehdr != NULL)
+	ld_state.ebl =
+	  ebl_openbackend_machine (ehdr->e_machine);
+
+      result = 1;
+    }
+  else if (elf_kind (elf) == ELF_K_AR)
+    {
+      /* Try the archive members.  This could
+	 potentially lead to wrong results if the
+	 archive contains files for more than one
+	 architecture.  But this is the user's
+	 problem.  */
+      Elf *subelf;
+      Elf_Cmd cmd = ELF_C_READ_MMAP;
+
+      while ((subelf = elf_begin (fd, cmd, elf)) != NULL)
+	{
+	  cmd = elf_next (subelf);
+
+	  if (try (fd, subelf) != 0)
+	    break;
+	}
+    }
+
+  elf_end (elf);
+
+  return result;
+}
+
+
 static void
 determine_output_format (void)
 {
@@ -1092,52 +1125,7 @@ determine_output_format (void)
 	  int fd = open (runp->name, O_RDONLY);
 	  if (fd != -1)
 	    {
-	      int try (Elf *elf)
-		{
-		  int result = 0;
-
-		  if (elf == NULL)
-		    return 0;
-
-		  if (elf_kind (elf) == ELF_K_ELF)
-		    {
-		      /* We have an ELF file.  We now can find out
-			 what the output format should be.  */
-		      XElf_Ehdr_vardef(ehdr);
-
-		      /* Get the ELF header of the object.  */
-		      xelf_getehdr (elf, ehdr);
-		      if (ehdr != NULL)
-			ld_state.ebl =
-			  ebl_openbackend_machine (ehdr->e_machine);
-
-		      result = 1;
-		    }
-		  else if (elf_kind (elf) == ELF_K_AR)
-		    {
-		      /* Try the archive members.  This could
-			 potentially lead to wrong results if the
-			 archive contains files for more than one
-			 architecture.  But this is the user's
-			 problem.  */
-		      Elf *subelf;
-		      Elf_Cmd cmd = ELF_C_READ_MMAP;
-
-		      while ((subelf = elf_begin (fd, cmd, elf)) != NULL)
-			{
-			  cmd = elf_next (subelf);
-
-			  if (try (subelf) != 0)
-			    break;
-			}
-		    }
-
-		  elf_end (elf);
-
-		  return result;
-		}
-
-	      if (try (elf_begin (fd, ELF_C_READ_MMAP, NULL)) != 0)
+	      if (try (fd, elf_begin (fd, ELF_C_READ_MMAP, NULL)) != 0)
 		/* Found a file.  */
 		break;
 	    }
